@@ -8,7 +8,7 @@ package CORBA::Python::CPyExtendedVisitor;
 use strict;
 use warnings;
 
-our $VERSION = '2.61';
+our $VERSION = '2.64';
 
 use CORBA::Python::CPyVisitor;
 use base qw(CORBA::Python::CPyVisitor);
@@ -48,7 +48,7 @@ sub open_stream {
 
 sub _get_defn {
     my $self = shift;
-    my ($defn) = @_;
+    my $defn = shift;
     if (ref $defn) {
         return $defn;
     }
@@ -535,6 +535,7 @@ sub visitSpecification {
         my $filename = 'c' . $py_name . 'module.c';
         $self->open_stream($filename);
         my $FH = $self->{out};
+        print $FH "/* ex: set ro: */\n";
         print $FH "/* This file was generated (by ",basename($0),"). DO NOT modify it */\n";
         print $FH "/* From file : ",$self->{srcname},", ",$self->{srcname_size}," octets, ",POSIX::ctime($self->{srcname_mtime});
         print $FH " */\n";
@@ -565,6 +566,11 @@ sub visitSpecification {
         print $FH "}\n";
         print $FH "\n";
         print $FH "/* end of file : ",$self->{filename}," */\n";
+        print $FH "/*\n";
+        print $FH " * Local variables:\n";
+        print $FH " *   buffer-read-only: t\n";
+        print $FH " * End:\n";
+        print $FH " */\n";    
         close $FH;
     }
 }
@@ -592,6 +598,7 @@ sub visitModules {
     $self->{methods} = q{};
     $self->{imp_mod} = {};
     my $FH = $self->{out};
+    print $FH "/* ex: set ro: */\n";
     print $FH "/* This file was generated (by ",basename($0),"). DO NOT modify it */\n";
     print $FH "/* From file : ",$self->{srcname},", ",$self->{srcname_size}," octets, ",POSIX::ctime($self->{srcname_mtime});
     print $FH " */\n";
@@ -620,6 +627,12 @@ sub visitModules {
     print $FH "}\n";
     print $FH "\n";
     print $FH "/* end of file : ",$self->{filename}," */\n";
+    print $FH "\n";
+    print $FH "/*\n";
+    print $FH " * Local variables:\n";
+    print $FH " *   buffer-read-only: t\n";
+    print $FH " * End:\n";
+    print $FH " */\n";    
     close $FH;
     $self->{out} = $save_out;
     $self->{init} = $save_init;
